.. Django Grappelli documentation master file, created by
   sphinx-quickstart on Sun Dec  5 19:11:46 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser
.. |version| replace:: 2.3.8

.. _index:

Documentation
=============

**A jazzy skin for the Django admin interface**.

This documentation covers version |version| of |grappelli|. |grappelli| is a grid-based alternative/extension to the `Django <http://www.djangoproject.com>`_ administration interface.

.. note::
    |grappelli| |version| requires Django 1.3. |grappelli| is always developed against the lastest stable Django release and is NOT tested with Djangos trunk.

Installation & Setup
--------------------

.. toctree::
   :maxdepth: 2
   
   quickstart
   customization

Dashboard
---------

.. toctree::
   :maxdepth: 2
   
   dashboard_setup
   dashboard_api
   dashboard_layout
   dashboard_extension

Internals
---------

.. toctree::
   :maxdepth: 2
   
   templates
   javascripts

Help
----

.. toctree::
   :maxdepth: 1
   
   faq
   thirdparty
   troubleshooting
   djangoissues
   releasenotes
   changelog

Code
----

https://github.com/sehmaschine/django-grappelli

Screenshots
-----------

http://sehmaschine.github.com/django-grappelli/

Discussion
----------

Use the `Grappelli Google Group <http://groups.google.com/group/django-grappelli>`_ to ask questions or discuss features.

